@@ -237,16 +237,15 @@ public class MailForm extends Composite  {
 			}
 			else if (isRecipientSet) {  //for sending message to a predefined user or users
 				myInput.clearList();
-				if (listToLogin.size() > 0)
-					myInput.addRecipient(getFullName(myInput.getAllUsers(), listToLogin.get(0)));
-				if (listToLogin.size() > 1) {
-					ArrayList<String> fullNames = new ArrayList<String>();
-					for (int i = 1; i < fullNames.size(); i++) {
-						String dest = fullNames.get(i);
-						fullNames.add(getFullName(myInput.getAllUsers(), dest));
-					}
-					myInput.addRecipients(fullNames);
-				}				
+				
+				ArrayList<String> fullNames = new ArrayList<String>();
+				for (String dest : listToLogin) {
+					fullNames.add(getFullName(myInput.getAllUsers(), dest));
+				}
+				myInput.addRecipients(fullNames);
+//				for (String dest : listToLogin) {
+//					myInput.addRecipient(getFullName(myInput.getAllUsers(), dest));
+//				}
 				GWT.log("subject.setFocus(true);");
 				setFocusOnSubject();				
 				isRecipientSet = false;
